# Self-driving lab Web UI
We don't define Self-driving labs (SDLs). We enable UI for them. 
## Description
Granting SDL flexibility makes it impossible to design a UI, yet it's a necessity for allowing more people to interact with it (democratisation). 
This web UI aims to ease up the control of any Python-based SDLs by displaying functions and parameters dynamically. 
With least modification of the current workflow, user can design, save and run their experiment and monitor the process. 


## Installation
```
pip install sdl-webui
```

## Usage
in your self-driving platform script, use `start_gui(__name__)`. Example in [sample_code.py](example/dummy_deck.py)
```python
from sdl_webui.app import start_gui
start_gui(__name__)
```


## Usage
coming soon
## Developing
coming soon

## Authors
Ivory Zhang

## License

